import {Image, ScrollView, View } from "@tarojs/components"
import Popup from "@/components/popup"
import classnames from "classnames";
import MCheckbox from "@/components/checkbox";
import LoadingCard from "@/components/loadingCard";
import InfiniteScroll from "@/components/infiniteScroll";
import styles from "./index.module.scss"
import { useEffect, useState } from "react";
import Taro from "@tarojs/taro";

type param = {
    show?: true|false,
    onClose?: () => void
}
export default ({show = false, onClose}: param) => {
    const selectList = ['剪板', '散剪', '大货']
    const [selectIndex, setSelectIndex] = useState(0)
    const selectProduct = (index:number) => {
        setSelectIndex(index)
    }

    const [list, setList] = useState<any[]>([])
    const [loading, setLoading] = useState(false)

    useEffect(() => {
        let lists:any[] = []
        for(let i = 0; i < 20; i++) {
            lists = [...lists, {
                title:`${i}#薄荷绿`,
                subtitle: '0770# 21S单面平纹(食毛)',
                tag: '剪板',
                select: i%2?true: false
            }]
        }
        setList([...lists])
    }, [])

    const [showPopup, setShowPopup] = useState(false)
    useEffect(() => {
        setShowPopup(show)
    }, [show])


    const [selectStatus, setSelectStatus] = useState(false)
    const selectAll = () => {
        list.map(item => {
            item.select = !selectStatus
        })
        setSelectStatus(!selectStatus)
        setList([...list])
    }

    //checkbox选中回调
    const selectCallBack = (item) => {
        item.select = true
        setList([...list])
    }

    //checkbox关闭回调
    const colseCallBack = (item) => {
        item.select = false
        setList([...list])
    }

    //popup关闭
    const closePopup = () => {
        onClose?.()
        setShowPopup(false)
    }

    const delSelect = () => {
        Taro.showModal({
            content: '删除所选商品？',
            success: function (res) {
                if (res.confirm) {
                    Taro.showToast({
                        title: '成功',
                        icon: 'success',
                        duration: 2000
                    })
                } else if (res.cancel) {
                console.log('用户点击取消')
                }
            }
        })
    }
    
    return (
        <View className={styles.shop_cart_main}>
            <Popup showTitle={false} show={showPopup} onClose={() => closePopup()}>
                <View className={styles.popup_con}>
                    <View className={styles.header}>0770# 21S单面平纹(食毛)</View>
                    <View className={styles.search}>
                        <View className={styles.search_title}>下单类型:</View>
                        <View className={styles.search_list}>
                            {selectList.map((item, index) => {
                                return <View key={index} onClick={() => selectProduct(index)} className={classnames(styles.search_item, (selectIndex==index)&&styles.search_item_select)}>{item}</View>
                            })}
                        </View>
                    </View>
                    <View className={styles.colorFind}>
                        <View className={styles.title}>颜色分类 (13)</View>
                        <View className={classnames('iconfont icon-sousuo', styles.miconfont)}></View>
                    </View>
                    <View className={styles.color_con}>
                        <View className={styles.item}>
                            <View className={styles.item_color}></View>
                            <View className={styles.item_con}>
                                <View className={styles.title}>1#薄荷绿</View>
                                <View className={styles.num}>¥25.5/m</View>
                            </View>
                            <View className={styles.btn_con}>
                                <View className={styles.btn}>添加</View>
                            </View>
                        </View>
                        <View className={styles.item}>
                            <View className={styles.item_color}></View>
                            <View className={styles.item_con}>
                                <View className={styles.title}>1#薄荷绿</View>
                                <View className={styles.num}>¥25.5/m</View>
                            </View>
                            <View className={styles.btn_con}>
                                <View className={styles.btn}>添加</View>
                            </View>
                        </View>
                        <View className={styles.item}>
                            <View className={styles.item_color}></View>
                            <View className={styles.item_con}>
                                <View className={styles.title}>1#薄荷绿</View>
                                <View className={styles.num}>¥25.5/m</View>
                            </View>
                            <View className={styles.btn_con}>
                                <View className={styles.btn}>添加</View>
                            </View>
                        </View>
                    </View>
                    <View className={styles.buy_btn}>
                        <View className={styles.icon}>
                            <View className={classnames('iconfont', 'icon-gouwuche', styles.miconfont)}></View>
                        </View>
                        <View className={styles.goPay}>
                            去结算
                        </View>
                    </View>
                </View>
            </Popup>
        </View>
    )
}